# Parallel

The parallel plug-in allows you to run multiple items at the same time, i.e. in parallel. This is convenient, for example, when you want to have a dynamic stimulus display and poll for responses at the same time.

**Note:** On some systems, threads (i.e. processes running in parallel) do not receive keyboard events. The first item from the parallel plug-in is executed in the main process. Therefore, if your items do not appear to respond to keyboard presses, try placing your keyboard response item as the first item in the parallel.
